@@ -44,6 +44,7 @@ import getpass
 import shutil
 import stat
 
+
 import logging
 
 # logging.basicConfig(level=logging.DEBUG, format='[%(levelname)s] (%(threadName)-10s) %(message)s',)
@@ -67,7 +68,7 @@ import logging
 #  Copy 'run.py' and 'settings.ini' files wherever you want to have your record repository.
 #  Windows let's you double click 'run.py'. Can run from desktop.
 # Magic number 42 is used to connect to all radios found in 'settings.ini'.
-print('0.6.5')
+print('0.6.62')
 
 # https://www.scrapehero.com/how-to-fake-and-rotate-user-agents-using-python-3/
 proxy_support = urllib.request.ProxyHandler({})
@@ -521,16 +522,19 @@ class GRecorder:
         self.url = url
         self.ini_key = ini_key
 
-    @staticmethod  # org pulls only NAME not PATH
+    @staticmethod  # copy keep-alive timeout=3000
     def thread_pull_song_name(url, ini_key):
-        # print(f'thread_pull_song_name: {ini_key}')
+        # print(f' thread_pull_song_name: {ini_key}')
         update_terminal = False
         stream_song_name = GRecorder.current_song_dict[ini_key]
         GIni.fail_meta_dict[url] = 'False'
+        headers = {'Connection': 'keep-alive'}
+        request = GNet.http_pool.request('GET', url, preload_content=False, retries=10, timeout=3000, headers=headers)
 
         while not GBase.exit_app:
+            hd = request.headers  # try keep conn. open
 
-            rand = random.randrange(5, 16, 1)   # sleep random to fool the watch dogs on web servers (5, 29, 1)
+            rand = random.randrange(5, 16, 1)   # sleep random servers (5, 29, 1), helped not much in snap container
             if GIni.srv_param_dict[ini_key + '_is_unknown_server'] == 'True':
                 if not GIni.fail_meta_dict[url] == 'True':  # let record go in one file
                     pass
@@ -584,7 +588,7 @@ class GRecorder:
             #        one file record with name
 
     @staticmethod
-    def search_pattern_start_record(title, ini_key):
+    def search_pattern_start(title, ini_key):
         # search title for strings to see if we should start recording this song/title
         search_list = []  # chop the string
         try:
@@ -730,8 +734,8 @@ class GRecorder:
 
                     fresh_song = stream_song_name  # check if it can be removed, we look in a dict now
                     clean_name = GBase.remove_special_chars(stream_song_name)
-                    if clean_name == '_no-name-record_no_split_':  # init name of title on startup
-                        clean_name = clean_name + GBase.this_time()
+                    if clean_name == 'untitled_full_record_':  # init name of title on startup
+                        clean_name = clean_name + radio_short_key + '_date_' + GBase.this_time()
                         clean_name = GBase.remove_special_chars(clean_name)
 
                     if first_record:
@@ -763,7 +767,7 @@ class GRecorder:
     @staticmethod  # org
     def ghetto_recorder_tail(url, key, path_to_save):
         # shall be as dump as possible
-        # print(f'ghetto_recorder_tail {key} ')
+        #print(f' ghetto_recorder_tail {key} ')
         stream_request_size = io.DEFAULT_BUFFER_SIZE
         old_time = time()
         must_run = False
@@ -783,12 +787,16 @@ class GRecorder:
                         print(f'----> start record: {key}')
                     break
 
-            request = GNet.http_pool.request('GET', url, preload_content=False, retries=10)
+            request = GNet.http_pool.request('GET', url, preload_content=False, retries=10,
+                                             headers={'Icy-MetaData': '1'})
+            icy_metadata = request.headers['icy-metaint']
+            icy_metadata = int(icy_metadata)
+
             while not GBase.exit_app:
                 with open(ghetto_recorder, 'wb') as record_file:
                     if brake_loop:                       # start_stop_recording stop, can change again to start at run.
                         break
-
+                    rand = random.randrange(4, 12, 2)  # sleep random
                     for chunk in request.stream(stream_request_size):                   # create file
 
                         if GIni.start_stop_recording[key] == 'stop':
@@ -820,10 +828,24 @@ class GRecorder:
                                 record_file.truncate()
                                 record_file.seek(0)
 
-                        ghetto_copy = GRecorder.path_to_song_dict[key]  # SET NEW PATH
-                        if time() - old_time > 20:
+                        if time() - old_time > rand:   # random rebuild conn., perhaps it helps in a snap container
                             old_time = time()
-                            # Do something (trigger header change?)
+                            # request object to def, get info from stream
+                            request = GNet.http_pool.request('GET', url, preload_content=False, retries=10,
+                                                             headers={'Icy-MetaData': '1'})
+                            request.read(icy_metadata)
+                            chunk_1b = request.read(1)
+                            chunk_1b = ord(chunk_1b)
+                            # \x03 hex value, was div. by 4; hex C (12d) * hex 4 = 30 48d; hex 3 (3d) * 16d = 48d;
+                            read_bytes = chunk_1b * 16
+                            read_bytes = int(read_bytes)
+                            metadata_content = request.read(read_bytes)
+                            metadata_content = metadata_content.decode('utf-8')
+                            title_info = metadata_content.split(";")
+                            title_info = title_info[0].split("=")
+                            title_info = GBase.remove_special_chars(title_info[1])
+                            print(title_info)
+                            break
                         if not chunk:
                             request = GNet.http_pool.request('GET', url, preload_content=False, retries=10)
 
