@@ -41,7 +41,7 @@ class UIWindow(tk.Tk):
     def __init__(self, radio_dir=None, settings_path=None):
         super().__init__()
         self.list_e = []
-        self.gr_version = '0.6.5'
+        self.gr_version = '0.6.6'
         self.radio_dir = radio_dir
         self.settings_path = settings_path
 
@@ -105,6 +105,7 @@ class UIWindow(tk.Tk):
         self.btn_browse.grid(row=1, column=1, padx=2, sticky='w')
         self.entry_bbr.grid(row=1, column=2, columnspan=3, padx=5, sticky='e')
         self.combo_timer.grid(row=1, column=5, padx=10, sticky='e')
+        self.combo_timer.current(3)
         self.combo_lang.grid(row=1, column=6, padx=10, sticky='e')
         self.combo_lang.current(0)
 
@@ -126,6 +127,8 @@ class UIWindow(tk.Tk):
                                          underline=0, bg='azure3')
         self.lbl_search_cb = tk.Label(self.canvas_frame, text='Search', bg='azure3')
         self.lbl_radio_cb = tk.Label(self.canvas_frame, text='Radio', bg='azure3')
+        self.lbl_search_middle = tk.Label(self.canvas_frame, text='Search option: Artist Title',
+                                          bg='azure3', foreground='blue')
 
         # bottom
 
@@ -264,6 +267,7 @@ class UIWindow(tk.Tk):
         self.ctr_mid.grid()  # init scrollbar connected frame
         self.canvas.grid_remove()  # remove start screen
 
+        self.lbl_search_middle.grid(row=0, column=1, sticky="ew")
         self.lbl_record_cb.grid(row=1, column=2, sticky="e")
         self.lbl_search_entry.grid(row=1, column=1, sticky="n")
         self.lbl_search_cb.grid(row=1, column=0, sticky="w")
@@ -485,7 +489,7 @@ class GhettoLanguage(UIWindow):
         ' Bei Titelwechseln kann noch ein Teil des folgenden',
         ' Titels aufgenommen werden. Einfach löschen.',
         ' Die "Uhr" oben rechts, falls mal keine Zeit da ist "Stop" zu drücken.',
-        ' Der Uhr ist eine wie rinr Eieruhr. Nur in Stunden. Fertig! :)',
+        ' Der Uhr ist wie eine Eieruhr. Nur in Stunden. Fertig! :)',
         ' Die Uhr kann man jederzeit ändern. Viel Spaß!',
     ]
 
@@ -512,6 +516,7 @@ class GhettoLanguage(UIWindow):
                 'label_bottom_info': ' Server down? Often under maintenance.',
                 'label_bottom_info_else': ' xxxxxxxxxxexxxxxxxxx.',
                 'label_search': 'Search',
+                'Label_search_info': 'Search option: Artist Title',
                 'entry_search_info': 'artist song (multi) (record if match): Elvis Ghetto concert'}
 
     dict_ger = {'button-edit': 'Radio Editor',
@@ -525,6 +530,7 @@ class GhettoLanguage(UIWindow):
                 'label_bottom_info': ' Server nicht erreichbar? Oft nur Wartungsarbeiten.',
                 'label_bottom_info_else': ' xxxxxxxxxxdxxxxxxxxx.',
                 'label_search': 'Suche',
+                'Label_search_info': 'Suchoption: Künstler Titel',
                 'entry_search_info': 'Interpret Titel (mehrere), Treffer/Aufnahme: Elvis Ghetto Beton'}
 
     def __init__(self):
@@ -553,7 +559,7 @@ class GhettoLanguage(UIWindow):
 
         uiw.lbl_search_cb.configure(text=dictionary['label_search'])
         uiw.lbl_search_entry.configure(text=dictionary['entry_search_info'])
-
+        uiw.lbl_search_middle.configure(text=dictionary['Label_search_info'])
 
 class UIUtils(UIWindow):
 
